@@ -309,7 +309,7 @@ class UnnestParser:
 
         if lower(next_token) == "with":
             next_token = next(tokens)
-            assert next_token == "offset"
+            assert lower(next_token) == "offset", next_token
             with_offset = True
 
             next_token = next(tokens, None)
@@ -503,10 +503,15 @@ class ExpressionParser:
                     next_token = next(tokens)
                     cast_type = Type(next_token)
                     expression = CastFunctionCall(column, cast_type)
+                    next_token = next(tokens)
+                    assert lower(next_token) == ")", next_token
                 else:
                     argument_tokens = get_tokens_until_closing_parenthesis(tokens)
+                    arguments_can_be_type = (
+                        "," in argument_tokens or lower(main_token) == "if"
+                    )
                     arguments = ExpressionListParser.parse(
-                        iter(argument_tokens), can_be_type=True
+                        iter(argument_tokens), can_be_type=arguments_can_be_type
                     )
                     expression = FunctionCall(main_token, *arguments)
                 next_token = next(tokens, None)
