@@ -89,7 +89,7 @@ class SelectStatement:
             statement_str += "\nGROUP BY{}".format(transform(self.group_by_clause))
 
         if self.having_clause:
-            statement_str += "\nHAVING {}".format(transform(self.having_clause))
+            statement_str += "\nHAVING{}".format(transform(self.having_clause))
 
         if self.order_by_clause:
             statement_str += "\nORDER BY{}".format(transform(self.order_by_clause))
@@ -227,9 +227,9 @@ class WhereClause(Expression):
     def transform(self):
         transformed_value = transform(self.value)
         if isinstance(self.value, Parenthesis) and "\n" in transformed_value:
-            return " (\n " + transform(self.value.args[0]) + "\n)"
+            return " (\n " + transform(self.value.args[0]).replace("\n", "\n ") + "\n)"
         if "\n" in transformed_value:
-            return "\n " + transformed_value
+            return "\n " + transformed_value.replace("\n", "\n ")
         return " " + transformed_value
 
     def validate(self, known_fields):
@@ -296,7 +296,12 @@ class GroupByClause(Expression):
 
 class HavingClause(Expression):
     def __str__(self):
-        return transform(self.value)
+        transformed_value = transform(self.value)
+        if isinstance(self.value, Parenthesis) and "\n" in transformed_value:
+            return " (\n " + transform(self.value.args[0]).replace("\n", "\n ") + "\n)"
+        if "\n" in transformed_value:
+            return "\n " + transformed_value.replace("\n", "\n ")
+        return " " + transformed_value
 
     def validate(self, known_fields):
         errors = super().validate(known_fields)
@@ -970,9 +975,9 @@ class Join(Expression):
             right_element,
         )
         if self.on:
-            join_str += "\nON {}".format(transform(self.on))
+            join_str += "\nON{}".format(transform(self.on))
         elif self.using:
-            join_str += "\nUSING {}".format(transform(self.using))
+            join_str += "\nUSING{}".format(transform(self.using))
         return join_str
 
     def __eq__(self, other):
@@ -1043,15 +1048,26 @@ class CombinedQueries(Expression):
 
 class OnClause(Expression):
     def __str__(self):
-        return transform(self.value)
+        transformed_value = transform(self.value)
+        if isinstance(self.value, Parenthesis) and "\n" in transformed_value:
+            return " (\n " + transform(self.value.args[0]).replace("\n", "\n ") + "\n)"
+        if "\n" in transformed_value:
+            return "\n " + transformed_value.replace("\n", "\n ")
+        return " " + transformed_value
 
 
 class UsingClause(Expression):
-    pass
+    def __str__(self):
+        transformed_value = transform(self.value)
+        if isinstance(self.value, Parenthesis) and "\n" in transformed_value:
+            return " (\n " + transform(self.value.args[0]).replace("\n", "\n ") + "\n)"
+        if "\n" in transformed_value:
+            return "\n " + transformed_value.replace("\n", "\n ")
+        return " " + transformed_value
 
 
 class Condition(Expression):
-    PREDICATES = ("=", ">", "<", "<=", ">=", "is", "like", "<>")
+    PREDICATES = ("=", ">", "<", "<=", ">=", "is", "like", "<>", "in")
 
     def __init__(self, expression, predicate, right_hand):
         super().__init__(expression)
@@ -1093,7 +1109,7 @@ class BooleanCondition(Expression):
         if len(transformed_condition) < DEFAULT_LINE_LENGTH and with_newline is False:
             return transformed_condition
 
-        join_str = "\n {} ".format(self.type.upper())
+        join_str = "\n{} ".format(self.type.upper())
         transformed_args = []
         for a in self.args:
             if isinstance(a, BooleanCondition):
@@ -1101,9 +1117,7 @@ class BooleanCondition(Expression):
             elif isinstance(a, Parenthesis):
                 transformed_a = transform(a.args[0])
                 if "\n" in transformed_a:
-                    transformed_a = (
-                        "(\n  " + transformed_a.replace("\n", "\n ") + "\n )"
-                    )
+                    transformed_a = "(\n " + transformed_a.replace("\n", "\n ") + "\n)"
                 else:
                     transformed_a = f"({transformed_a})"
             else:
@@ -1187,10 +1201,23 @@ class Case(Expression):
             case_str += " {}".format(transform(self.value))
 
         case_str += "\n "
-        case_str += "\n ".join(
-            "WHEN {} THEN {}".format(transform(when), transform(then))
-            for when, then in self.when_then
-        )
+        when_then_block_str = []
+        for when, then in self.when_then:
+            when_then_str = "WHEN"
+            transformed_when = transform(when)
+            if isinstance(when, Parenthesis) and "\n" in transformed_when:
+                when_then_str += (
+                    " (\n  " + transform(when.args[0]).replace("\n", "\n  ") + "\n )\n "
+                )
+            elif "\n" in transformed_when:
+                when_then_str += "\n  " + transformed_when.replace("\n", "\n  ") + "\n "
+            else:
+                when_then_str += " " + transformed_when + " "
+
+            when_then_str += f"THEN {then}"
+            when_then_block_str.append(when_then_str)
+
+        case_str += "\n ".join(when_then_block_str)
 
         if self.else_expression:
             case_str += "\n ELSE {}".format(transform(self.else_expression))
